@@ -12,13 +12,13 @@
 static char *
 gnome_dirrelative_file (char *base, char *sub, char *filename)
 {
-	static char *gnomedir = NULL;
+        static char *gnomedir = NULL;
 	char *f, *t, *u;
-
+	
 	/* First try the env GNOMEDIR relative path */
 	if (!gnomedir)
 		gnomedir = getenv ("GNOMEDIR");
-
+	
 	if (gnomedir){
 		t = g_concat_dir_and_file (gnomedir, sub);
 		u = g_copy_strings (t, "/", filename, NULL);
@@ -26,7 +26,7 @@ gnome_dirrelative_file (char *base, char *sub, char *filename)
 		
 		if (g_file_exists (u))
 			return u;
-	
+		
 		g_free (u);
 	}
 	
@@ -147,3 +147,49 @@ g_concat_dir_and_file (const char *dir, const char *file)
 	else
 		return g_copy_strings (dir, PATH_SEP_STR, file, NULL);
 }
+
+
+/* returns the home directory of the user
+ * This one is NOT to be free'd as it points into the 
+ * env structure.
+ * 
+ */
+
+gchar *gnome_util_user_home(void)
+{
+	static gchar *home_dir;
+	static gint init = 1;
+	
+	if (init) {
+		home_dir = getenv("HOME");
+		init = 0;
+	}
+	
+	return(home_dir);
+}
+
+/* pass in a string, and it will add the users home dir ie,
+ * pass in .gnome/bookmarks.html and it will return
+ * /home/imain/.gnome/bookmarks.html
+ * 
+ * Remember to g_free() returned value! */
+gchar *gnome_util_prepend_user_home(char *file)
+{
+	gchar *home_return;
+	home_return = g_malloc (strlen(file) + strlen(gnome_util_user_home()) + 3);
+	
+	sprintf(home_return, "%s/%s", gnome_util_user_home(), file);
+	return(home_return);
+}
+
+/* very similar to above, but adds $HOME/.gnome/ to beginning
+ * This is meant to be the most useful version.
+ */
+gchar *gnome_util_home_file(char *file)
+{
+	gchar *home_return;
+	home_return = g_malloc (strlen(file) + strlen(gnome_util_user_home()) + 16);
+	
+	sprintf(home_return, "%s/.gnome/%s", gnome_util_user_home(), file);
+	return(home_return);
+}
