@@ -14,9 +14,9 @@ typedef enum {
 
 GnomePropertyConfigurator *gnome_property_configurator_new     (void);
 
-void                      gnome_property_configurator_destroy  (GnomePropertyConfigurator *this);
+void                      gnome_property_configurator_destroy  (GnomePropertyConfigurator *);
 
-void                      gnome_property_configurator_register (GnomePropertyConfigurator *this, 
+void                      gnome_property_configurator_register (GnomePropertyConfigurator *, 
 							        GtkWidget *title_widget,
 								GtkWidget *content_widget,
 								int (*callback)(GnomePropertyRequest));
