@@ -2,17 +2,17 @@
  * Screen Saver property configurator
  * Written by Radek Doulik, 1997 <doulik@karlin.mff.cuni.cz>
  */
+
 #include "property-screensaver.h"
 #include "xlockmore.h"
 #include <stdio.h>
 #include <stdarg.h>
 #include <gtk/gtk.h>
+#include <libintl.h>
 #include "gnome.h"
 #include "gnome-desktop.h"
-#include "gtkpreviewextra.h"
 
-/* static GtkWidget *frame;   */
-/* static GtkWidget *monitor; */
+#define _(String) gettext(String)
 
 struct SelectInfo {
 	ConfigScreenSaver *th;
@@ -168,6 +168,7 @@ ConfigScreenSaver::modes_frame ()
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	mlist = gtk_list_new ();
+	gtk_list_set_selection_mode (GTK_LIST (mlist), GTK_SELECTION_BROWSE);
 	gtk_widget_set_usize (f, 220, -1);
 	vb1 = gtk_vbox_new (FALSE, 10);
 	b1 = gtk_button_new_with_label ("Setup");
@@ -224,7 +225,7 @@ ConfigScreenSaver::ConfigScreenSaver (GtkWidget *window)
 	GtkWidget *settings, *modes;
 	
 	ssavers = g_list_alloc ();
-	curMode = 0;
+	curMode = NULL;
 	
 	vbox = gtk_vbox_new (TRUE, 0);
 	hbox = gtk_hbox_new (TRUE, 0);
@@ -277,6 +278,6 @@ screensaver_setup (GtkWidget *window)
 
 	sc = prepareConfigScreenSaver (window);
 
-	register_extension (gtk_label_new ("Screen saver"), sc, NULL);
+	register_extension (gtk_label_new (_(" Screen saver ")), sc, NULL);
 }
 }
